"""add quicklook workflow

Revision ID: 2dec906ab81a
Revises: 1c0f67cc24aa
Create Date: 2022-08-09 14:30:35.587508

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "2dec906ab81a"
down_revision = "1c0f67cc24aa"
branch_labels = None
depends_on = None

dag = """JOB FETCH vlass_ql_fetch.condor
VARS FETCH jobname="$(JOB)"

JOB ENVOY vlass_ql_envoy.condor
VARS ENVOY jobname="$(JOB)"

JOB AUTOQA vlass_ql_auto_qa.condor
VARS AUTOQA jobname="$(JOB)"

PARENT FETCH CHILD ENVOY
PARENT ENVOY CHILD AUTOQA
"""

fetch_script = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./pimscache ln -c $1 -p $2 $3

"""

fetch_condor = """executable = vlass_ql_fetch.sh
arguments = {{calibration_name}} {{phase_center}} {{data_location}}/rawdata

output = ql_fetch.out
error = ql_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
PIMS_PATH = /lustre/aoc/cluster/pipeline/vlass_{{vlass_env}}/workspaces/bin
VLASS_DIR = {{data_location}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(PIMS_PATH)/pimscache
when_to_transfer_output = ON_EXIT
transfer_output_files = .job.ad
output_destination = nraorsync://$(VLASS_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
request_memory = 2G
requirements = HasLustre == True

queue
"""

envoy_script = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit

./casa_envoy --vlass-img $1 $2
"""

envoy_condor = """executable = vlass_ql_envoy.sh
arguments = metadata.json PPR.xml {{request_id}}

output = ql_envoy.out
error = ql_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
VLASS_DIR = {{data_location}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/.matplotlib, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/casa_envoy, nraorsync://$(SBIN_PATH)/vela, nraorsync://$(VLASS_DIR)/working, nraorsync://$(VLASS_DIR)/rawdata, nraorsync://$(VLASS_DIR)/products{{#remote}}, nraorsync://$(VLASS_DIR)/{{profile}}.properties{{/remote}}, nraorsync://$(VLASS_DIR)/PPR.xml, nraorsync://$(VLASS_DIR)/metadata.json{{files_to_transfer}}
transfer_output_files = .job.ad
+nrao_output_files = "working rawdata products"
when_to_transfer_output = ON_EXIT
output_destination = nraorsync://$(VLASS_DIR)
+WantIOProxy = True

request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue
"""

qa_script = """#!/bin/sh

source /lustre/aoc/cluster/pipeline/vlass_{{vlass_env}}/workspaces/bin/activate
export CAPO_PROFILE=vlass.{{vlass_env}}

JOB_ID=$1
printf "JOB_ID = %s\n" $JOB_ID

cd working/
CASA_LOG_FILE=`ls casa-*.log`
../../../../workspaces/bin/annotateQa.py --jobid $JOB_ID $CASA_LOG_FILE

"""

qa_condor = """executable = vlass_ql_auto_qa.sh
arguments = {{manager_job_id}}

output = ql_auto_qa.out
error = ql_auto_qa.err
log = condor.log

should_transfer_files = NO

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""


def upgrade():
    op.execute(
        """
        INSERT INTO workflows (workflow_name, uses_casa) VALUES ('vlass_quicklook', true)
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('vlass_ql_fetch.sh', E'{fetch_script}', 'vlass_quicklook') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('vlass_ql_fetch.condor', E'{fetch_condor}', 'vlass_quicklook') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('vlass_ql_envoy.sh', E'{envoy_script}', 'vlass_quicklook') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('vlass_ql_envoy.condor', E'{envoy_condor}', 'vlass_quicklook') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('vlass_ql_auto_qa.sh', E'{qa_script}', 'vlass_quicklook') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('vlass_ql_auto_qa.condor', E'{qa_condor}', 'vlass_quicklook') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('vlass_ql.dag', E'{dag}', 'vlass_quicklook') 
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflows WHERE workflow_name = 'vlass_quicklook'
        """
    )
    op.execute(
        """
        DELETE FROM workflow_templates WHERE workflow_name = 'vlass_quicklook'
        """
    )
